pub struct TimeEvent { /* private fields */ }Expand description
A named duration measurement. The duration is reported when TimeEvent::end runs.
Implementations
Sourceimpl TimeEvent
impl TimeEvent
Sourcepub fn new(
message: impl Into<String>,
on_end: Option<Box<dyn FnOnce(Duration) + Send>>,
) -> Self
pub fn new( message: impl Into<String>, on_end: Option<Box<dyn FnOnce(Duration) + Send>>, ) -> Self
Starts a timer with message and an optional callback invoked by TimeEvent::end.
Sourcepub fn stop(self) -> Duration
pub fn stop(self) -> Duration
Returns the elapsed duration, consuming the event without invoking the callback.