ILogger

Trait ILogger 

pub trait ILogger: Send + Sync {
    // Required methods
    fn info<'life0, 'life1, 'async_trait>(
        &'life0 self,
        msg: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn debug<'life0, 'life1, 'async_trait>(
        &'life0 self,
        msg: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn warn<'life0, 'life1, 'async_trait>(
        &'life0 self,
        msg: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn error<'life0, 'life1, 'async_trait>(
        &'life0 self,
        msg: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn exec<'life0, 'life1, 'async_trait>(
        &'life0 self,
        msg: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn time(&self, msg: &str) -> TimeEvent;
}
Logging interface with leveled async logging plus timed events.

Required Methods

fn info<'life0, 'life1, 'async_trait>( &'life0 self, msg: &'life1 str, ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Logs at info level.

fn debug<'life0, 'life1, 'async_trait>( &'life0 self, msg: &'life1 str, ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Logs at debug level (suppressed by ConsoleLogger in production).

fn warn<'life0, 'life1, 'async_trait>( &'life0 self, msg: &'life1 str, ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Logs at warn level.

fn error<'life0, 'life1, 'async_trait>( &'life0 self, msg: &'life1 str, ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Logs at error level.

fn exec<'life0, 'life1, 'async_trait>( &'life0 self, msg: &'life1 str, ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Logs an executed action at info level with an exec marker.

fn time(&self, msg: &str) -> TimeEvent

Starts a TimeEvent that logs its duration when ended.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors