pub struct TimeDebouncers;Expand description
Factory for trailing, leading, and trailing-value debouncers.
Implementations
Sourceimpl TimeDebouncers
impl TimeDebouncers
Sourcepub fn trailing<F>(delay: Duration, action: F) -> Arc<TrailingDebouncer> ⓘ
pub fn trailing<F>(delay: Duration, action: F) -> Arc<TrailingDebouncer> ⓘ
Builds a debouncer that runs action once after delay elapses without another trigger.
Panics via the debouncer constructor when delay is zero.
Sourcepub fn leading<F>(window: Duration, action: F) -> Arc<LeadingDebouncer> ⓘ
pub fn leading<F>(window: Duration, action: F) -> Arc<LeadingDebouncer> ⓘ
Builds a debouncer that runs action immediately when outside window,
otherwise ignores the trigger. Panics via the constructor when window is zero.
Sourcepub fn trailing_value<T, F>(
delay: Duration,
action: F,
) -> Arc<TrailingValueDebouncer<T>> ⓘ
pub fn trailing_value<T, F>( delay: Duration, action: F, ) -> Arc<TrailingValueDebouncer<T>> ⓘ
Builds a debouncer that runs action with the latest value after delay
elapses without another trigger. Panics via the constructor when delay is zero.